# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/mocap/Vicon.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.math.Vec3DDouble_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/mocap/Vicon.proto',
  package='rst.devices.mocap',
  serialized_pb='\n\x1drst/devices/mocap/Vicon.proto\x12\x11rst.devices.mocap\x1a\x1arst/math/Vec3DDouble.proto\"\xa5\x06\n\x05Vicon\x12\r\n\x05\x66rame\x18\x01 \x02(\x04\x12\x33\n\x08timecode\x18\x02 \x01(\x0b\x32!.rst.devices.mocap.Vicon.Timecode\x12\x31\n\x07subject\x18\x03 \x03(\x0b\x32 .rst.devices.mocap.Vicon.Subject\x12\x42\n\x10unlabeled_marker\x18\x04 \x03(\x0b\x32(.rst.devices.mocap.Vicon.UnlabeledMarker\x1aK\n\x0fUnlabeledMarker\x12\x0c\n\x04name\x18\x01 \x02(\t\x12*\n\x0btranslation\x18\x02 \x02(\x0b\x32\x15.rst.math.Vec3DDouble\x1a\x64\n\x08Timecode\x12\r\n\x05hours\x18\x01 \x02(\r\x12\x0f\n\x07minutes\x18\x02 \x02(\r\x12\x0f\n\x07seconds\x18\x03 \x02(\r\x12\x11\n\x06\x66rames\x18\x04 \x01(\r:\x01\x30\x12\x14\n\tsub_frame\x18\x05 \x01(\r:\x01\x30\x1a\xe0\x02\n\x07Segment\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x38\n\x07markers\x18\x02 \x03(\x0b\x32\'.rst.devices.mocap.Vicon.Segment.Marker\x12*\n\x0btranslation\x18\x03 \x01(\x0b\x32\x15.rst.math.Vec3DDouble\x12\x30\n\x11\x65uler_orientation\x18\x04 \x01(\x0b\x32\x15.rst.math.Vec3DDouble\x12\x32\n\x13helical_orientation\x18\x05 \x01(\x0b\x32\x15.rst.math.Vec3DDouble\x12\x37\n\x18quaternionen_orientation\x18\x06 \x01(\x0b\x32\x15.rst.math.Vec3DDouble\x1a\x42\n\x06Marker\x12\x0c\n\x04name\x18\x01 \x02(\t\x12*\n\x0btranslation\x18\x02 \x02(\x0b\x32\x15.rst.math.Vec3DDouble\x1aK\n\x07Subject\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x32\n\x08segments\x18\x02 \x03(\x0b\x32 .rst.devices.mocap.Vicon.SegmentB\x0b\x42\tViconType')




_VICON_UNLABELEDMARKER = _descriptor.Descriptor(
  name='UnlabeledMarker',
  full_name='rst.devices.mocap.Vicon.UnlabeledMarker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.mocap.Vicon.UnlabeledMarker.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation', full_name='rst.devices.mocap.Vicon.UnlabeledMarker.translation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=277,
  serialized_end=352,
)

_VICON_TIMECODE = _descriptor.Descriptor(
  name='Timecode',
  full_name='rst.devices.mocap.Vicon.Timecode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hours', full_name='rst.devices.mocap.Vicon.Timecode.hours', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minutes', full_name='rst.devices.mocap.Vicon.Timecode.minutes', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds', full_name='rst.devices.mocap.Vicon.Timecode.seconds', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frames', full_name='rst.devices.mocap.Vicon.Timecode.frames', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sub_frame', full_name='rst.devices.mocap.Vicon.Timecode.sub_frame', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=354,
  serialized_end=454,
)

_VICON_SEGMENT_MARKER = _descriptor.Descriptor(
  name='Marker',
  full_name='rst.devices.mocap.Vicon.Segment.Marker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.mocap.Vicon.Segment.Marker.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation', full_name='rst.devices.mocap.Vicon.Segment.Marker.translation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=743,
  serialized_end=809,
)

_VICON_SEGMENT = _descriptor.Descriptor(
  name='Segment',
  full_name='rst.devices.mocap.Vicon.Segment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.mocap.Vicon.Segment.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='markers', full_name='rst.devices.mocap.Vicon.Segment.markers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation', full_name='rst.devices.mocap.Vicon.Segment.translation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='euler_orientation', full_name='rst.devices.mocap.Vicon.Segment.euler_orientation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='helical_orientation', full_name='rst.devices.mocap.Vicon.Segment.helical_orientation', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quaternionen_orientation', full_name='rst.devices.mocap.Vicon.Segment.quaternionen_orientation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_VICON_SEGMENT_MARKER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=457,
  serialized_end=809,
)

_VICON_SUBJECT = _descriptor.Descriptor(
  name='Subject',
  full_name='rst.devices.mocap.Vicon.Subject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.mocap.Vicon.Subject.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='segments', full_name='rst.devices.mocap.Vicon.Subject.segments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=811,
  serialized_end=886,
)

_VICON = _descriptor.Descriptor(
  name='Vicon',
  full_name='rst.devices.mocap.Vicon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame', full_name='rst.devices.mocap.Vicon.frame', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timecode', full_name='rst.devices.mocap.Vicon.timecode', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='rst.devices.mocap.Vicon.subject', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unlabeled_marker', full_name='rst.devices.mocap.Vicon.unlabeled_marker', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_VICON_UNLABELEDMARKER, _VICON_TIMECODE, _VICON_SEGMENT, _VICON_SUBJECT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=81,
  serialized_end=886,
)

_VICON_UNLABELEDMARKER.fields_by_name['translation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_UNLABELEDMARKER.containing_type = _VICON;
_VICON_TIMECODE.containing_type = _VICON;
_VICON_SEGMENT_MARKER.fields_by_name['translation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_SEGMENT_MARKER.containing_type = _VICON_SEGMENT;
_VICON_SEGMENT.fields_by_name['markers'].message_type = _VICON_SEGMENT_MARKER
_VICON_SEGMENT.fields_by_name['translation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_SEGMENT.fields_by_name['euler_orientation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_SEGMENT.fields_by_name['helical_orientation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_SEGMENT.fields_by_name['quaternionen_orientation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_SEGMENT.containing_type = _VICON;
_VICON_SUBJECT.fields_by_name['segments'].message_type = _VICON_SEGMENT
_VICON_SUBJECT.containing_type = _VICON;
_VICON.fields_by_name['timecode'].message_type = _VICON_TIMECODE
_VICON.fields_by_name['subject'].message_type = _VICON_SUBJECT
_VICON.fields_by_name['unlabeled_marker'].message_type = _VICON_UNLABELEDMARKER
DESCRIPTOR.message_types_by_name['Vicon'] = _VICON

class Vicon(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class UnlabeledMarker(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _VICON_UNLABELEDMARKER

    # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon.UnlabeledMarker)

  class Timecode(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _VICON_TIMECODE

    # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon.Timecode)

  class Segment(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType

    class Marker(_message.Message):
      __metaclass__ = _reflection.GeneratedProtocolMessageType
      DESCRIPTOR = _VICON_SEGMENT_MARKER

      # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon.Segment.Marker)
    DESCRIPTOR = _VICON_SEGMENT

    # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon.Segment)

  class Subject(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _VICON_SUBJECT

    # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon.Subject)
  DESCRIPTOR = _VICON

  # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\tViconType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/audition/FormattedSoundChunk.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.audition.FloatSoundArray_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/audition/FormattedSoundChunk.proto',
  package='rst.audition',
  serialized_pb='\n&rst/audition/FormattedSoundChunk.proto\x12\x0crst.audition\x1a\"rst/audition/FloatSoundArray.proto\"\xa7\x01\n\x13\x46ormattedSoundChunk\x12+\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1d.rst.audition.FloatSoundArray\x12\x0c\n\x04rate\x18\x02 \x02(\r\x12\x13\n\x08\x63hannels\x18\x03 \x01(\r:\x01\x32\"@\n\x0b\x43hannelType\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\x12\t\n\x05\x46RONT\x10\x03\x12\x08\n\x04REAR\x10\x04\x42\x19\x42\x17\x46ormattedSoundChunkType')



_FORMATTEDSOUNDCHUNK_CHANNELTYPE = _descriptor.EnumDescriptor(
  name='ChannelType',
  full_name='rst.audition.FormattedSoundChunk.ChannelType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FRONT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REAR', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=196,
  serialized_end=260,
)


_FORMATTEDSOUNDCHUNK = _descriptor.Descriptor(
  name='FormattedSoundChunk',
  full_name='rst.audition.FormattedSoundChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.audition.FormattedSoundChunk.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate', full_name='rst.audition.FormattedSoundChunk.rate', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='rst.audition.FormattedSoundChunk.channels', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FORMATTEDSOUNDCHUNK_CHANNELTYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=93,
  serialized_end=260,
)

_FORMATTEDSOUNDCHUNK.fields_by_name['data'].message_type = rst.audition.FloatSoundArray_pb2._FLOATSOUNDARRAY
_FORMATTEDSOUNDCHUNK_CHANNELTYPE.containing_type = _FORMATTEDSOUNDCHUNK;
DESCRIPTOR.message_types_by_name['FormattedSoundChunk'] = _FORMATTEDSOUNDCHUNK

class FormattedSoundChunk(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FORMATTEDSOUNDCHUNK

  # @@protoc_insertion_point(class_scope:rst.audition.FormattedSoundChunk)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027FormattedSoundChunkType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/nao/NaoTemperatures.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/nao/NaoTemperatures.proto',
  package='rst.devices.nao',
  serialized_pb='\n%rst/devices/nao/NaoTemperatures.proto\x12\x0frst.devices.nao\"a\n\x0fNaoTemperatures\x12\r\n\x05\x62oard\x18\x01 \x01(\x02\x12\x0c\n\x04head\x18\x02 \x01(\x02\x12\x31\n\x06joints\x18\x03 \x03(\x0b\x32!.rst.devices.nao.JointTemperature\"5\n\x10JointTemperature\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x13\n\x0btemperature\x18\x02 \x02(\x02\x42\x15\x42\x13NaoTemperaturesType')




_NAOTEMPERATURES = _descriptor.Descriptor(
  name='NaoTemperatures',
  full_name='rst.devices.nao.NaoTemperatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='board', full_name='rst.devices.nao.NaoTemperatures.board', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='head', full_name='rst.devices.nao.NaoTemperatures.head', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='joints', full_name='rst.devices.nao.NaoTemperatures.joints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=58,
  serialized_end=155,
)


_JOINTTEMPERATURE = _descriptor.Descriptor(
  name='JointTemperature',
  full_name='rst.devices.nao.JointTemperature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.nao.JointTemperature.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='rst.devices.nao.JointTemperature.temperature', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=157,
  serialized_end=210,
)

_NAOTEMPERATURES.fields_by_name['joints'].message_type = _JOINTTEMPERATURE
DESCRIPTOR.message_types_by_name['NaoTemperatures'] = _NAOTEMPERATURES
DESCRIPTOR.message_types_by_name['JointTemperature'] = _JOINTTEMPERATURE

class NaoTemperatures(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _NAOTEMPERATURES

  # @@protoc_insertion_point(class_scope:rst.devices.nao.NaoTemperatures)

class JointTemperature(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _JOINTTEMPERATURE

  # @@protoc_insertion_point(class_scope:rst.devices.nao.JointTemperature)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\023NaoTemperaturesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/audition/FloatSoundArray.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/audition/FloatSoundArray.proto',
  package='rst.audition',
  serialized_pb='\n\"rst/audition/FloatSoundArray.proto\x12\x0crst.audition\"&\n\x0f\x46loatSoundArray\x12\x13\n\x0b\x66loatbuffer\x18\x01 \x03(\x02\x42\x15\x42\x13\x46loatSoundArrayType')




_FLOATSOUNDARRAY = _descriptor.Descriptor(
  name='FloatSoundArray',
  full_name='rst.audition.FloatSoundArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='floatbuffer', full_name='rst.audition.FloatSoundArray.floatbuffer', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=52,
  serialized_end=90,
)

DESCRIPTOR.message_types_by_name['FloatSoundArray'] = _FLOATSOUNDARRAY

class FloatSoundArray(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FLOATSOUNDARRAY

  # @@protoc_insertion_point(class_scope:rst.audition.FloatSoundArray)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\023FloatSoundArrayType')
# @@protoc_insertion_point(module_scope)



import sys
import pkgutil

import rst
import rstsandbox
import rstdeprecated
import logging

logger = logging.getLogger("rstdeprecated")
# prevent logging warnings about missing handlers as per:
# https://docs.python.org/2.6/library/logging.html#configuring-logging-for-a-library
# do so before importing anything from RSB itself, which might already log
# stuff
class _NullHandler(logging.Handler):
    """
    Null logging handler to prevent warning messages
    """
    def emit(self, record):
        pass
logger.addHandler(_NullHandler())

def addDeprecatedToRST():
    def importIt(designator, error = True):
        logger.debug("importIt called with '%s'" % designator)
        if hasattr(designator, '__iter__'):
            name = '.'.join(designator)
        else:
            name = designator
        try:
            logger.debug("Really importing name '%s'" % name)
            return __import__(name, fromlist = [ '__dict__' ]) # WT?
        except Exception, e:
            if error:
                raise e

    # Find two things within the deprecated:
    # + All Modules (since there should be no duplicates between rst
    #   and rstdeprecated)
    # + Packages which do not have a corresponding package relative to
    #   the rst package.
    #   E.g. rstdeprecated.communicationpatterns when there is no
    #   rst.communicationpatterns
    # We record errors caused by dependency problems so the caller can
    # trigger additional iterations to resolve dependencies.
    def findModules(root):
        result = []
        errors = []
        for _, name, ispkg in pkgutil.iter_modules(root.__path__):
            fullname = root.__name__ + '.' + name
            if ispkg:
                kind = 'package'
            else:
                kind = 'module'
            logger.debug("Processing %s %s.%s", kind, root.__name__, name)
            logger.debug('Importing %s', fullname)
            try:
                loaded = importIt(fullname)
                logger.debug('Loaded %s', loaded)
                proposedRstName = [ 'rst' ] + fullname.split('.')[1:]
                logger.debug("Checking whether %s in rst exists" % proposedRstName)
                if ispkg and importIt(proposedRstName, error = False):
                    logger.debug('%s is a package which also exists under rst', fullname)
                    subresult, suberrors = findModules(loaded)
                    result.extend(subresult)
                    errors.extend(suberrors)
                else:
                    result.append(loaded)
            except Exception, e:
                errors.append((name, "%s: %s" % (type(e).__name__, e)))
                logger.warn('Failed to load %s: %s', name, e)
        return result, errors

    # Process packages and modules that are present in the deprecated,
    # but not in the stable section:
    # + Add package or module to respective parent package. This
    #   corresponds to "mounting" the entire module tree rooted at the
    #   particular package under the parent package in the stable
    #   section.
    # + Add to sys.modules
    modules, errors = findModules(rstdeprecated)
    logger.debug("Found modules %s and errors %s" % (modules, errors))
    for module in modules:

        logger.debug("Processing module or package %s" % module)

        components = module.__name__.split('.')
        rstName    = 'rst.' + '.'.join(components[1:])
        logger.debug('Mounting %s -> %s', module.__name__, rstName)

        sys.modules[rstName] = module
        rstPackage = importIt([ 'rst' ] + components[1:-1])
        rstPackage.__dict__[components[-1]] = module


    return modules, errors

# We need multiple iterations to resolve dependencies since deprecated
# types may depend on each other. Since we do not attempt to load the
# modules in a dependency-respecting order, some modules may initially
# fail to load but succeed later, after their dependencies have been
# loaded.
logger.debug("---- ITERATION ----")
_, initial = addDeprecatedToRST()
while len(initial) > 0:
    logger.debug("---- ITERATION ----")
    _, new = addDeprecatedToRST()
    if len(new) == len(initial):
        raise RuntimeError, "Unable to install modules/packages in rst namespace:\n%s" \
            % '\n'.join([("%s - %s" % (e[0], e[1])) for e in new])
    initial = new



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/deprecated/DoNotUseMe.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/deprecated/DoNotUseMe.proto',
  package='rst.deprecated',
  serialized_pb='\n\x1frst/deprecated/DoNotUseMe.proto\x12\x0erst.deprecated\"\x0c\n\nDoNotUseMeB\x10\x42\x0e\x44oNotUseMeType')




_DONOTUSEME = _descriptor.Descriptor(
  name='DoNotUseMe',
  full_name='rst.deprecated.DoNotUseMe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=51,
  serialized_end=63,
)

DESCRIPTOR.message_types_by_name['DoNotUseMe'] = _DONOTUSEME

class DoNotUseMe(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _DONOTUSEME

  # @@protoc_insertion_point(class_scope:rst.deprecated.DoNotUseMe)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016DoNotUseMeType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/nao/Modules.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/nao/Modules.proto',
  package='rst.devices.nao',
  serialized_pb='\n\x1drst/devices/nao/Modules.proto\x12\x0frst.devices.nao\"j\n\x07Modules\x12(\n\x07modules\x18\x01 \x03(\x0b\x32\x17.rst.devices.nao.Module\x12\x35\n\x14\x66ramemanager_modules\x18\x02 \x03(\x0b\x32\x17.rst.devices.nao.Module\"\x16\n\x06Module\x12\x0c\n\x04name\x18\x01 \x02(\tB\rB\x0bModulesType')




_MODULES = _descriptor.Descriptor(
  name='Modules',
  full_name='rst.devices.nao.Modules',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modules', full_name='rst.devices.nao.Modules.modules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framemanager_modules', full_name='rst.devices.nao.Modules.framemanager_modules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=50,
  serialized_end=156,
)


_MODULE = _descriptor.Descriptor(
  name='Module',
  full_name='rst.devices.nao.Module',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.nao.Module.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=158,
  serialized_end=180,
)

_MODULES.fields_by_name['modules'].message_type = _MODULE
_MODULES.fields_by_name['framemanager_modules'].message_type = _MODULE
DESCRIPTOR.message_types_by_name['Modules'] = _MODULES
DESCRIPTOR.message_types_by_name['Module'] = _MODULE

class Modules(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MODULES

  # @@protoc_insertion_point(class_scope:rst.devices.nao.Modules)

class Module(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MODULE

  # @@protoc_insertion_point(class_scope:rst.devices.nao.Module)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\013ModulesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/JointState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/JointState.proto',
  package='rst.kinematics',
  serialized_pb='\n\x1frst/kinematics/JointState.proto\x12\x0erst.kinematics\"b\n\nJointState\x12\x0c\n\x04name\x18\x01 \x02(\x0c\x12\r\n\x05value\x18\x02 \x02(\x02\x12\x11\n\tstiffness\x18\x03 \x01(\x02\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\x02\x12\x13\n\x0btemperature\x18\x05 \x01(\x02\x42\x10\x42\x0eJointStateType')




_JOINTSTATE = _descriptor.Descriptor(
  name='JointState',
  full_name='rst.kinematics.JointState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.kinematics.JointState.name', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='rst.kinematics.JointState.value', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stiffness', full_name='rst.kinematics.JointState.stiffness', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command', full_name='rst.kinematics.JointState.command', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='rst.kinematics.JointState.temperature', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=51,
  serialized_end=149,
)

DESCRIPTOR.message_types_by_name['JointState'] = _JOINTSTATE

class JointState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _JOINTSTATE

  # @@protoc_insertion_point(class_scope:rst.kinematics.JointState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016JointStateType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/nao/System.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/nao/System.proto',
  package='rst.devices.nao',
  serialized_pb='\n\x1crst/devices/nao/System.proto\x12\x0frst.devices.nao\"3\n\x06System\x12\x12\n\nrobot_name\x18\x01 \x02(\t\x12\x15\n\rnaoqi_version\x18\x02 \x01(\tB\x0c\x42\nSystemType')




_SYSTEM = _descriptor.Descriptor(
  name='System',
  full_name='rst.devices.nao.System',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='robot_name', full_name='rst.devices.nao.System.robot_name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='naoqi_version', full_name='rst.devices.nao.System.naoqi_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=49,
  serialized_end=100,
)

DESCRIPTOR.message_types_by_name['System'] = _SYSTEM

class System(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SYSTEM

  # @@protoc_insertion_point(class_scope:rst.devices.nao.System)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\nSystemType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/audition/InterauralTimeDifference.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/audition/InterauralTimeDifference.proto',
  package='rst.audition',
  serialized_pb='\n+rst/audition/InterauralTimeDifference.proto\x12\x0crst.audition\"c\n\x18InterauralTimeDifference\x12\r\n\x05value\x18\x01 \x03(\x02\x12\x0e\n\x06weight\x18\x02 \x03(\x02\x12\x13\n\x0b\x66rame_shift\x18\x03 \x02(\x02\x12\x13\n\x0btime_window\x18\x04 \x02(\x02\x42\x1e\x42\x1cInterauralTimeDifferenceType')




_INTERAURALTIMEDIFFERENCE = _descriptor.Descriptor(
  name='InterauralTimeDifference',
  full_name='rst.audition.InterauralTimeDifference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rst.audition.InterauralTimeDifference.value', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weight', full_name='rst.audition.InterauralTimeDifference.weight', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frame_shift', full_name='rst.audition.InterauralTimeDifference.frame_shift', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_window', full_name='rst.audition.InterauralTimeDifference.time_window', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=61,
  serialized_end=160,
)

DESCRIPTOR.message_types_by_name['InterauralTimeDifference'] = _INTERAURALTIMEDIFFERENCE

class InterauralTimeDifference(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _INTERAURALTIMEDIFFERENCE

  # @@protoc_insertion_point(class_scope:rst.audition.InterauralTimeDifference)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\034InterauralTimeDifferenceType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/GroupHypothesis.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.math.MatrixDouble_pb2
import rst.tracking.TrackingInfo_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/GroupHypothesis.proto',
  package='rst.hri',
  serialized_pb='\n\x1drst/hri/GroupHypothesis.proto\x12\x07rst.hri\x1a\x1brst/math/MatrixDouble.proto\x1a\x1frst/tracking/TrackingInfo.proto\"\xcd\x04\n\x0fGroupHypothesis\x12\x31\n\rtracking_info\x18\x01 \x01(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12\x1b\n\x13group_size_estimate\x18\n \x01(\r\x12\x42\n\x13group_size_category\x18\x0b \x01(\x0e\x32%.rst.hri.GroupHypothesis.SizeCategory\x12\x16\n\x0einterest_level\x18\x14 \x01(\x02\x12\x17\n\x0fgroup_stability\x18\x15 \x01(\x02\x12:\n\x0c\x61ge_category\x18\x1e \x01(\x0e\x32$.rst.hri.GroupHypothesis.AgeCategory\x12@\n\x0fgender_category\x18\x1f \x01(\x0e\x32\'.rst.hri.GroupHypothesis.GenderCategory\x12.\n\x0estability_cues\x18( \x01(\x0b\x32\x16.rst.math.MatrixDouble\"?\n\x0b\x41geCategory\x12\x0c\n\x08\x43HILDREN\x10\x01\x12\n\n\x06\x41\x44ULTS\x10\x02\x12\x0b\n\x07SENIORS\x10\x04\x12\t\n\x05MIXED\x10\x08\"O\n\x0eGenderCategory\x12\x11\n\rMIXED_GENDERS\x10\x01\x12\x15\n\x11\x43OMPLETELY_FEMALE\x10\x02\x12\x13\n\x0f\x43OMPLETELY_MALE\x10\x04\"5\n\x0cSizeCategory\x12\x0f\n\x0bSMALL_GROUP\x10\x01\x12\t\n\x05GROUP\x10\x02\x12\t\n\x05\x43ROWD\x10\x04\x42\x15\x42\x13GroupHypothesisType')



_GROUPHYPOTHESIS_AGECATEGORY = _descriptor.EnumDescriptor(
  name='AgeCategory',
  full_name='rst.hri.GroupHypothesis.AgeCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHILDREN', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADULTS', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENIORS', index=2, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MIXED', index=3, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=495,
  serialized_end=558,
)

_GROUPHYPOTHESIS_GENDERCATEGORY = _descriptor.EnumDescriptor(
  name='GenderCategory',
  full_name='rst.hri.GroupHypothesis.GenderCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MIXED_GENDERS', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETELY_FEMALE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETELY_MALE', index=2, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=560,
  serialized_end=639,
)

_GROUPHYPOTHESIS_SIZECATEGORY = _descriptor.EnumDescriptor(
  name='SizeCategory',
  full_name='rst.hri.GroupHypothesis.SizeCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SMALL_GROUP', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CROWD', index=2, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=641,
  serialized_end=694,
)


_GROUPHYPOTHESIS = _descriptor.Descriptor(
  name='GroupHypothesis',
  full_name='rst.hri.GroupHypothesis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tracking_info', full_name='rst.hri.GroupHypothesis.tracking_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_size_estimate', full_name='rst.hri.GroupHypothesis.group_size_estimate', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_size_category', full_name='rst.hri.GroupHypothesis.group_size_category', index=2,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interest_level', full_name='rst.hri.GroupHypothesis.interest_level', index=3,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_stability', full_name='rst.hri.GroupHypothesis.group_stability', index=4,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='age_category', full_name='rst.hri.GroupHypothesis.age_category', index=5,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gender_category', full_name='rst.hri.GroupHypothesis.gender_category', index=6,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stability_cues', full_name='rst.hri.GroupHypothesis.stability_cues', index=7,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GROUPHYPOTHESIS_AGECATEGORY,
    _GROUPHYPOTHESIS_GENDERCATEGORY,
    _GROUPHYPOTHESIS_SIZECATEGORY,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=105,
  serialized_end=694,
)

_GROUPHYPOTHESIS.fields_by_name['tracking_info'].message_type = rst.tracking.TrackingInfo_pb2._TRACKINGINFO
_GROUPHYPOTHESIS.fields_by_name['group_size_category'].enum_type = _GROUPHYPOTHESIS_SIZECATEGORY
_GROUPHYPOTHESIS.fields_by_name['age_category'].enum_type = _GROUPHYPOTHESIS_AGECATEGORY
_GROUPHYPOTHESIS.fields_by_name['gender_category'].enum_type = _GROUPHYPOTHESIS_GENDERCATEGORY
_GROUPHYPOTHESIS.fields_by_name['stability_cues'].message_type = rst.math.MatrixDouble_pb2._MATRIXDOUBLE
_GROUPHYPOTHESIS_AGECATEGORY.containing_type = _GROUPHYPOTHESIS;
_GROUPHYPOTHESIS_GENDERCATEGORY.containing_type = _GROUPHYPOTHESIS;
_GROUPHYPOTHESIS_SIZECATEGORY.containing_type = _GROUPHYPOTHESIS;
DESCRIPTOR.message_types_by_name['GroupHypothesis'] = _GROUPHYPOTHESIS

class GroupHypothesis(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _GROUPHYPOTHESIS

  # @@protoc_insertion_point(class_scope:rst.hri.GroupHypothesis)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\023GroupHypothesisType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/euroc/ColoredPoseSet.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Pose_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/euroc/ColoredPoseSet.proto',
  package='rst.euroc',
  serialized_pb='\n\x1erst/euroc/ColoredPoseSet.proto\x12\trst.euroc\x1a\x17rst/geometry/Pose.proto\"\xec\x01\n\x0e\x43oloredPoseSet\x12\x34\n\x05poses\x18\x01 \x03(\x0b\x32%.rst.euroc.ColoredPoseSet.ColoredPose\x1a\xa3\x01\n\x0b\x43oloredPose\x12 \n\x04pose\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12:\n\x05\x63olor\x18\x02 \x02(\x0b\x32+.rst.euroc.ColoredPoseSet.ColoredPose.Color\x12\x0c\n\x04type\x18\x03 \x01(\t\x1a(\n\x05\x43olor\x12\t\n\x01r\x18\x01 \x02(\x01\x12\t\n\x01g\x18\x02 \x02(\x01\x12\t\n\x01\x62\x18\x03 \x02(\x01\x42\x14\x42\x12\x43oloredPoseSetType')




_COLOREDPOSESET_COLOREDPOSE_COLOR = _descriptor.Descriptor(
  name='Color',
  full_name='rst.euroc.ColoredPoseSet.ColoredPose.Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='r', full_name='rst.euroc.ColoredPoseSet.ColoredPose.Color.r', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g', full_name='rst.euroc.ColoredPoseSet.ColoredPose.Color.g', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='rst.euroc.ColoredPoseSet.ColoredPose.Color.b', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=267,
  serialized_end=307,
)

_COLOREDPOSESET_COLOREDPOSE = _descriptor.Descriptor(
  name='ColoredPose',
  full_name='rst.euroc.ColoredPoseSet.ColoredPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='rst.euroc.ColoredPoseSet.ColoredPose.pose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='rst.euroc.ColoredPoseSet.ColoredPose.color', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.euroc.ColoredPoseSet.ColoredPose.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_COLOREDPOSESET_COLOREDPOSE_COLOR, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=144,
  serialized_end=307,
)

_COLOREDPOSESET = _descriptor.Descriptor(
  name='ColoredPoseSet',
  full_name='rst.euroc.ColoredPoseSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='poses', full_name='rst.euroc.ColoredPoseSet.poses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_COLOREDPOSESET_COLOREDPOSE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=71,
  serialized_end=307,
)

_COLOREDPOSESET_COLOREDPOSE_COLOR.containing_type = _COLOREDPOSESET_COLOREDPOSE;
_COLOREDPOSESET_COLOREDPOSE.fields_by_name['pose'].message_type = rst.geometry.Pose_pb2._POSE
_COLOREDPOSESET_COLOREDPOSE.fields_by_name['color'].message_type = _COLOREDPOSESET_COLOREDPOSE_COLOR
_COLOREDPOSESET_COLOREDPOSE.containing_type = _COLOREDPOSESET;
_COLOREDPOSESET.fields_by_name['poses'].message_type = _COLOREDPOSESET_COLOREDPOSE
DESCRIPTOR.message_types_by_name['ColoredPoseSet'] = _COLOREDPOSESET

class ColoredPoseSet(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class ColoredPose(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType

    class Color(_message.Message):
      __metaclass__ = _reflection.GeneratedProtocolMessageType
      DESCRIPTOR = _COLOREDPOSESET_COLOREDPOSE_COLOR

      # @@protoc_insertion_point(class_scope:rst.euroc.ColoredPoseSet.ColoredPose.Color)
    DESCRIPTOR = _COLOREDPOSESET_COLOREDPOSE

    # @@protoc_insertion_point(class_scope:rst.euroc.ColoredPoseSet.ColoredPose)
  DESCRIPTOR = _COLOREDPOSESET

  # @@protoc_insertion_point(class_scope:rst.euroc.ColoredPoseSet)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\022ColoredPoseSetType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/ProprioceptionState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.JointState_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/ProprioceptionState.proto',
  package='rst.kinematics',
  serialized_pb='\n(rst/kinematics/ProprioceptionState.proto\x12\x0erst.kinematics\x1a\x1frst/kinematics/JointState.proto\"A\n\x13ProprioceptionState\x12*\n\x06joints\x18\x01 \x03(\x0b\x32\x1a.rst.kinematics.JointStateB\x19\x42\x17ProprioceptionStateType')




_PROPRIOCEPTIONSTATE = _descriptor.Descriptor(
  name='ProprioceptionState',
  full_name='rst.kinematics.ProprioceptionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='rst.kinematics.ProprioceptionState.joints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=93,
  serialized_end=158,
)

_PROPRIOCEPTIONSTATE.fields_by_name['joints'].message_type = rst.kinematics.JointState_pb2._JOINTSTATE
DESCRIPTOR.message_types_by_name['ProprioceptionState'] = _PROPRIOCEPTIONSTATE

class ProprioceptionState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PROPRIOCEPTIONSTATE

  # @@protoc_insertion_point(class_scope:rst.kinematics.ProprioceptionState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027ProprioceptionStateType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/CameraMatrix3x4.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/CameraMatrix3x4.proto',
  package='rst.vision',
  serialized_pb='\n rst/vision/CameraMatrix3x4.proto\x12\nrst.vision\"\xad\x01\n\x0f\x43\x61meraMatrix3x4\x12\x0b\n\x03\x63\x31\x31\x18\x01 \x02(\x02\x12\x0b\n\x03\x63\x31\x32\x18\x02 \x02(\x02\x12\x0b\n\x03\x63\x31\x33\x18\x03 \x02(\x02\x12\x0b\n\x03\x63\x31\x34\x18\x04 \x02(\x02\x12\x0b\n\x03\x63\x32\x31\x18\x05 \x02(\x02\x12\x0b\n\x03\x63\x32\x32\x18\x06 \x02(\x02\x12\x0b\n\x03\x63\x32\x33\x18\x07 \x02(\x02\x12\x0b\n\x03\x63\x32\x34\x18\x08 \x02(\x02\x12\x0b\n\x03\x63\x33\x31\x18\t \x02(\x02\x12\x0b\n\x03\x63\x33\x32\x18\n \x02(\x02\x12\x0b\n\x03\x63\x33\x33\x18\x0b \x02(\x02\x12\x0b\n\x03\x63\x33\x34\x18\x0c \x02(\x02\x42\x15\x42\x13\x43\x61meraMatrix3x4Type')




_CAMERAMATRIX3X4 = _descriptor.Descriptor(
  name='CameraMatrix3x4',
  full_name='rst.vision.CameraMatrix3x4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='c11', full_name='rst.vision.CameraMatrix3x4.c11', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c12', full_name='rst.vision.CameraMatrix3x4.c12', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c13', full_name='rst.vision.CameraMatrix3x4.c13', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c14', full_name='rst.vision.CameraMatrix3x4.c14', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c21', full_name='rst.vision.CameraMatrix3x4.c21', index=4,
      number=5, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c22', full_name='rst.vision.CameraMatrix3x4.c22', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c23', full_name='rst.vision.CameraMatrix3x4.c23', index=6,
      number=7, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c24', full_name='rst.vision.CameraMatrix3x4.c24', index=7,
      number=8, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c31', full_name='rst.vision.CameraMatrix3x4.c31', index=8,
      number=9, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c32', full_name='rst.vision.CameraMatrix3x4.c32', index=9,
      number=10, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c33', full_name='rst.vision.CameraMatrix3x4.c33', index=10,
      number=11, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c34', full_name='rst.vision.CameraMatrix3x4.c34', index=11,
      number=12, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=49,
  serialized_end=222,
)

DESCRIPTOR.message_types_by_name['CameraMatrix3x4'] = _CAMERAMATRIX3X4

class CameraMatrix3x4(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CAMERAMATRIX3X4

  # @@protoc_insertion_point(class_scope:rst.vision.CameraMatrix3x4)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\023CameraMatrix3x4Type')
# @@protoc_insertion_point(module_scope)



# ============================================================
#
# Copyright (C) 2011 by Johannes Wienke <jwienke at techfak dot uni-bielefeld dot de>
#
# This program is free software; you can redistribute it
# and/or modify it under the terms of the GNU General
# Public License as published by the Free Software Foundation;
# either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# ============================================================

from setuptools import setup
from setuptools import find_packages
from setuptools import Command

class PrintOutputs(Command):
    """
    Prints out the generated output names.

    @author: jwienke
    """

    user_options = []
    description = "Prints the generated output names."

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        c = self.get_finalized_command('bdist_egg')
        for o in c.get_outputs():
            print("##### %s" % o)

setup(name='rstdeprecated',
      version='0.16.0',
      description='''
                  Robotics Systems Types - Deprecated
                  ''',
      author='Johannes Wienke',
      author_email='jwienke@techfak.uni-bielefeld.de',
      license="GPLv3",
      url="https://code.cor-lab.org/projects/rst",

      packages=find_packages(exclude=['build', 'rst.*', 'rst', 'rstsandbox']),

      install_requires=['protobuf==2.5.0'],

      cmdclass={'print_outputs' : PrintOutputs},

      )



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/CalibrationMatrices.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.vision.CameraMatrix3x4_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/CalibrationMatrices.proto',
  package='rst.vision',
  serialized_pb='\n$rst/vision/CalibrationMatrices.proto\x12\nrst.vision\x1a rst/vision/CameraMatrix3x4.proto\"l\n\x13\x43\x61librationMatrices\x12)\n\x04left\x18\x01 \x02(\x0b\x32\x1b.rst.vision.CameraMatrix3x4\x12*\n\x05right\x18\x02 \x02(\x0b\x32\x1b.rst.vision.CameraMatrix3x4B\x19\x42\x17\x43\x61librationMatricesType')




_CALIBRATIONMATRICES = _descriptor.Descriptor(
  name='CalibrationMatrices',
  full_name='rst.vision.CalibrationMatrices',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='left', full_name='rst.vision.CalibrationMatrices.left', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='right', full_name='rst.vision.CalibrationMatrices.right', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=86,
  serialized_end=194,
)

_CALIBRATIONMATRICES.fields_by_name['left'].message_type = rst.vision.CameraMatrix3x4_pb2._CAMERAMATRIX3X4
_CALIBRATIONMATRICES.fields_by_name['right'].message_type = rst.vision.CameraMatrix3x4_pb2._CAMERAMATRIX3X4
DESCRIPTOR.message_types_by_name['CalibrationMatrices'] = _CALIBRATIONMATRICES

class CalibrationMatrices(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CALIBRATIONMATRICES

  # @@protoc_insertion_point(class_scope:rst.vision.CalibrationMatrices)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027CalibrationMatricesType')
# @@protoc_insertion_point(module_scope)
